import { geoNaturalEarth1, geoPath, geoGraticule, geoMercator } from 'd3';

const projection = geoNaturalEarth1();
const path = geoPath(projection);
const graticule = geoGraticule();

export const Marks = ({
  mapData: { land, interiors },
  nuclearData,
  longitude,
  latitude,
  name,
  sizeScale,
  sizeValue,
  colorScale,
  colorValue,
  onClick
}) => (
  <>
    <g className="marks">
      <path className="sphere" d={path({ type: 'Sphere' })} />
      <path className="graticules" d={path(graticule())} />
      {land.features.map(feature => (
        <path className="land" d={path(feature)} />
      ))}
      <path className="interiors" d={path(interiors)} />
      {nuclearData.map(d => {
        const [x, y] = projection([longitude(d), latitude(d)]);
        return (
          <g
            onClick={() => {
              onClick(d);
            }}
          >
            <circle
              className="points"
              cx={x}
              cy={y}
              fill={colorScale(colorValue(d))}
              r={sizeScale(sizeValue(d))}
            >
              <title>
                {name(d)}: {latitude(d)}, {longitude(d)}
              </title>
            </circle>
          </g>
        );
      })}
    </g>
  </>
);
